Package: shinyjqui
Type: Package
Title: 'jQuery UI' Interactions and Effects for Shiny
Version: 0.4.1
Authors@R: person("Yang", "Tang", email = "tang_yang@outlook.com",
  role = c("aut", "cre"))
Maintainer: Yang Tang <tang_yang@outlook.com>
Description: An extension to shiny that brings interactions and animation effects from
    'jQuery UI' library.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 3.2.0)
Imports: shiny (>= 1.5.0), htmltools, htmlwidgets, jsonlite, rlang
Suggests: ggplot2, highcharter, knitr, markdown, rmarkdown, plotly
URL: https://github.com/yang-tang/shinyjqui,
        https://yang-tang.github.io/shinyjqui/
BugReports: https://github.com/yang-tang/shinyjqui/issues
RoxygenNote: 7.1.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2022-02-03 06:36:22 UTC; tangy53
Author: Yang Tang [aut, cre]
Repository: CRAN
Date/Publication: 2022-02-03 07:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 16:55:17 UTC; unix
